@@ -871,7 +871,6 @@ typedef NS_ENUM(NSInteger, VLCPanType) {
     BOOL mediaHasProjection = [_vpc currentMediaIs360Video];
     _fov = mediaHasProjection ? DEFAULT_FOV : 0.f;
 
-    [_panRecognizer setEnabled:mediaHasProjection];
     [_swipeRecognizerUp setEnabled:!mediaHasProjection];
     [_swipeRecognizerDown setEnabled:!mediaHasProjection];
     [_swipeRecognizerLeft setEnabled:!mediaHasProjection];
@@ -882,10 +881,19 @@ typedef NS_ENUM(NSInteger, VLCPanType) {
     }
 }
 
-- (void)deviceMotionHasAttitudeWithDeviceMotion:(VLCDeviceMotion *)deviceMotion pitch:(double)pitch yaw:(double)yaw roll:(double)roll
+- (void)applyYaw:(CGFloat)diffYaw pitch:(CGFloat)diffPitch;
+{
+    //Add and limit new pitch and yaw
+    self.deviceMotion.yaw += diffYaw;
+    self.deviceMotion.pitch += diffPitch;
+
+    [_vpc updateViewpoint:self.deviceMotion.yaw pitch:self.deviceMotion.pitch roll:0 fov:_fov absolute:YES];
+}
+
+- (void)deviceMotionHasAttitudeWithDeviceMotion:(VLCDeviceMotion *)deviceMotion pitch:(double)pitch yaw:(double)yaw
 {
     if (_panRecognizer.state != UIGestureRecognizerStateChanged || UIGestureRecognizerStateBegan) {
-        [_vpc updateViewpoint:yaw pitch:pitch roll:roll fov:_fov absolute:YES];
+        [self applyYaw:yaw pitch:pitch];
     }
 }
 #pragma mark - controls
@@ -1435,7 +1443,6 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
     if (panRecognizer.state == UIGestureRecognizerStateEnded) {
         _currentPanType = VLCPanTypeNone;
         if ([_vpc currentMediaIs360Video]) {
-            [_deviceMotion lastAngleWithYaw:_vpc.yaw pitch:_vpc.pitch roll:_vpc.roll];
             [_deviceMotion startDeviceMotion];
         }
     }
@@ -1450,13 +1457,10 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
     _saveLocation = newLocationInView;
 
     //screenSizePixel width is used twice to get a constant speed on the movement.
-    CGFloat yaw = _fov * -diffX / _screenPixelSize.width;
-    CGFloat pitch = _fov * -diffY / _screenPixelSize.width;
+    CGFloat diffYaw = _fov * -diffX / _screenPixelSize.width;
+    CGFloat diffPitch = _fov * -diffY / _screenPixelSize.width;
 
-    CGFloat newYaw = _vpc.yaw + yaw;
-    CGFloat newPitch = _vpc.pitch + pitch;
-
-    [_vpc updateViewpoint:newYaw pitch:newPitch roll:_vpc.roll fov:_vpc.fov absolute:YES];
+    [self applyYaw:diffYaw pitch:diffPitch];
 }
 
 - (void)swipeRecognized:(UISwipeGestureRecognizer*)swipeRecognizer
@@ -1669,11 +1673,15 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
 - (void)showOnDisplay:(UIView *)view
 {
     // if we don't have a renderer we're mirroring and don't want to show the dialog
-    BOOL displayExternally = _vpc.renderer && view != _movieView;
-    [_playingExternalView shouldDisplay:displayExternally];
+    BOOL displayExternally = view != _movieView;
+    [_playingExternalView shouldDisplay:displayExternally movieView:_movieView];
     [_playingExternalView updateUIWithRendererItem:_vpc.renderer];
-    _vpc.videoOutputView = view;
     _artworkImageView.hidden = displayExternally;
+    if (!displayExternally && _movieView.superview != self.view) {
+        [self.view addSubview:_movieView];
+        [self.view sendSubviewToBack:_movieView];
+        _movieView.frame = self.view.frame;
+    }
 }
 
 - (void)handleExternalScreenDidConnect:(NSNotification *)notification
