@@ -70,6 +70,7 @@ typedef NS_ENUM(NSUInteger, VLCAspectRatio) {
     VLCDialogProvider *_dialogProvider;
 
     NSMutableArray *_shuffleStack;
+    void (^_playbackCompletion)(BOOL success);
 }
 
 @end
@@ -142,8 +143,14 @@ typedef NS_ENUM(NSUInteger, VLCAspectRatio) {
     [_mediaPlayer addPlaybackSlave:[NSURL fileURLWithPath:pathToFile] type:VLCMediaPlaybackSlaveTypeSubtitle enforce:YES];
 }
 
-- (void)playMediaList:(VLCMediaList *)mediaList firstIndex:(NSInteger)index subtitlesFilePath:(NSString *)subsFilePath
+- (void)playMediaList:(VLCMediaList *)mediaList firstIndex:(NSInteger)index subtitlesFilePath:(NSString * _Nullable)subsFilePath
 {
+    [self playMediaList: mediaList firstIndex: index subtitlesFilePath: subsFilePath completion: nil];
+}
+
+- (void)playMediaList:(VLCMediaList *)mediaList firstIndex:(NSInteger)index subtitlesFilePath:(NSString * _Nullable)subsFilePath completion:(void (^ __nullable)(BOOL success))completion
+{
+    _playbackCompletion = completion;
     self.mediaList = mediaList;
     _itemInMediaListToBePlayedFirst = (int)index;
     _pathToExternalSubtitlesFile = subsFilePath;
@@ -297,20 +304,9 @@ typedef NS_ENUM(NSUInteger, VLCAspectRatio) {
     _playerIsSetup = NO;
     [_shuffleStack removeAllObjects];
 
-    if (@available(iOS 10, *)) {
-        if (_errorCallback && _mediaPlayer.state == VLCMediaPlayerStateError &&  !_sessionWillRestart)
-            [[UIApplication sharedApplication] openURL:_errorCallback options:@{} completionHandler:nil];
-        else if (_successCallback && !_sessionWillRestart)
-            [[UIApplication sharedApplication] openURL:_successCallback options:@{} completionHandler:nil];
-    } else {
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wdeprecated-declarations"
-        /* UIApplication's replacement calls require iOS 10 or later, which we can't enforce as of yet */
-        if (_errorCallback && _mediaPlayer.state == VLCMediaPlayerStateError &&  !_sessionWillRestart)
-            [[UIApplication sharedApplication] openURL:_errorCallback];
-        else if (_successCallback && !_sessionWillRestart)
-            [[UIApplication sharedApplication] openURL:_successCallback];
-#pragma clang diagnostic pop
+    if (_playbackCompletion) {
+        BOOL finishedPlaybackWithError = _mediaPlayer.state == VLCMediaPlayerStateError &&  !_sessionWillRestart;
+        _playbackCompletion(!finishedPlaybackWithError);
     }
 
     [[self remoteControlService] unsubscribeFromRemoteCommands];
@@ -592,19 +588,11 @@ typedef NS_ENUM(NSUInteger, VLCAspectRatio) {
 
 - (void)toggleRepeatMode
 {
-    VLCRepeatMode nextRepeatMode = VLCDoNotRepeat;
-    switch (_listPlayer.repeatMode) {
-        case VLCDoNotRepeat:
-            nextRepeatMode = VLCRepeatCurrentItem;
-            break;
-        case VLCRepeatCurrentItem:
-            nextRepeatMode = VLCRepeatAllItems;
-            break;
-        default:
-            nextRepeatMode = VLCDoNotRepeat;
-            break;
+    if (_listPlayer.repeatMode == VLCRepeatAllItems) {
+        _listPlayer.repeatMode = VLCDoNotRepeat;
+    } else {
+        _listPlayer.repeatMode += 1;
     }
-    _listPlayer.repeatMode = nextRepeatMode;
 }
 
 - (NSInteger)indexOfCurrentAudioTrack
@@ -756,16 +744,12 @@ typedef NS_ENUM(NSUInteger, VLCAspectRatio) {
         case VLCMediaPlayerStateStopped: {
             [_listPlayer.mediaList lock];
             NSUInteger listCount = _listPlayer.mediaList.count;
+            [_listPlayer.mediaList unlock];
             if ([_listPlayer.mediaList indexOfMedia:_mediaPlayer.media] == listCount - 1 && self.repeatMode == VLCDoNotRepeat) {
-                [_listPlayer.mediaList unlock];
                 _sessionWillRestart = NO;
                 [self stopPlayback];
                 return;
-            } else if (listCount > 1) {
-                [_listPlayer.mediaList unlock];
-                [_listPlayer next];
-            } else
-                [_listPlayer.mediaList unlock];
+            }
         } break;
         case VLCMediaPlayerStateESAdded: {
 #if TARGET_OS_IOS
@@ -1356,7 +1340,7 @@ typedef NS_ENUM(NSUInteger, VLCAspectRatio) {
 }
 
 #pragma mark - Renderer
-- (void)setRenderer:(VLCRendererItem *)renderer
+- (void)setRenderer:(VLCRendererItem * __nullable)renderer
 {
     _renderer = renderer;
     [_mediaPlayer setRendererItem:_renderer];
